@@ -52,8 +52,9 @@ module Google
         #
         # @return [void]
         def prepare!
-          set_xgac
-          if options && options.api_format_version
+          set_api_client_header
+          set_user_project_header
+          if options&.api_format_version
             header['X-Goog-Api-Format-Version'] = options.api_format_version.to_s
           end
           query[FIELDS_PARAM] = normalize_fields_param(query[FIELDS_PARAM]) if query.key?(FIELDS_PARAM)
@@ -82,6 +83,7 @@ module Google
           return super if options && options.skip_deserialization
           return super if content_type.nil?
           return nil unless content_type.start_with?(JSON_CONTENT_TYPE)
+          body = "{}" if body.empty?
           instance = response_class.new
           response_representation.new(instance).from_json(body, unwrap: response_class)
           instance
@@ -126,17 +128,28 @@ module Google
 
         private
 
-        def set_xgac
+        def set_api_client_header
           old_xgac = header
             .find_all { |k, v| k.downcase == 'x-goog-api-client' }
             .map { |(a, b)| b }
             .join(' ')
+            .split
+            .find_all { |s| s !~ %r{^gl-ruby/|^gdcl/} }
+            .join(' ')
           xgac = "gl-ruby/#{RUBY_VERSION} gdcl/#{Google::Apis::VERSION}"
           xgac = old_xgac.empty? ? xgac : "#{old_xgac} #{xgac}"
           header.delete_if { |k, v| k.downcase == 'x-goog-api-client' }
           header['X-Goog-Api-Client'] = xgac
         end
 
+        def set_user_project_header
+          quota_project_id = options.quota_project
+          if !quota_project_id && options&.authorization.respond_to?(:quota_project_id)
+            quota_project_id = options.authorization.quota_project_id
+          end
+          header['X-Goog-User-Project'] = quota_project_id if quota_project_id
+        end
+
         # Attempt to parse a JSON error message
         # @param [String] body
         #  HTTP response body
