@@ -271,7 +271,7 @@ module Google
         #   Current page token & service instance
         # @yieldparam [String] token
         #   Current page token to be used in the query
-        # @yieldparm [service]
+        # @yieldparam [service]
         #   Current service instance
         # @since 0.9.4
         #
@@ -334,7 +334,13 @@ module Google
         #  Request-specific options
         # @return [Google::Apis::Core::DownloadCommand]
         def make_simple_command(method, path, options)
-          template = Addressable::Template.new(root_url + base_path + path)
+          full_path =
+            if path.start_with? "/"
+              path[1..-1]
+            else
+              base_path + path
+            end
+          template = Addressable::Template.new(root_url + full_path)
           command = ApiCommand.new(method, template)
           command.options = request_options.merge(options)
           apply_command_defaults(command)
