@@ -145,7 +145,7 @@ module Google
           options.authorization.respond_to?(:apply!)
         end
 
-        # Prepare the request (e.g. calculate headers, serialize data, etc) before sending
+        # Prepare the request (e.g. calculate headers, add query params, serialize data, etc) before sending
         #
         # @private
         # @return [void]
@@ -153,6 +153,7 @@ module Google
           normalize_unicode = true
           if options
             header.update(options.header) if options.header
+            query.update(options.query) if options.query
             normalize_unicode = options.normalize_unicode
           end
           self.url = url.expand(params, nil, normalize_unicode) if url.is_a?(Addressable::Template)
@@ -198,7 +199,6 @@ module Google
         #
         # @param [Fixnum] status
         #   HTTP status code of response
-        # @param
         # @param [Hash] header
         #   HTTP response headers
         # @param [String] body
@@ -316,7 +316,7 @@ module Google
         end
 
         # Update the request with any specified options.
-        # @param [Hash] header
+        # @param [Hash] req_header
         #  HTTP headers
         # @return [void]
         def apply_request_options(req_header)
@@ -385,14 +385,16 @@ module Google
           return unless @opencensus_span
           return unless OpenCensus::Trace.span_context
 
-          if @http_res.body.respond_to? :bytesize
-            @opencensus_span.put_message_event \
-              OpenCensus::Trace::SpanBuilder::RECEIVED, 1, @http_res.body.bytesize
-          end
-          status = @http_res.status.to_i
-          if status > 0
-            @opencensus_span.set_status map_http_status status
-            @opencensus_span.put_attribute "http.status_code", status
+          if @http_res
+            if @http_res.body.respond_to? :bytesize
+              @opencensus_span.put_message_event \
+                OpenCensus::Trace::SpanBuilder::RECEIVED, 1, @http_res.body.bytesize
+            end
+            status = @http_res.status.to_i
+            if status > 0
+              @opencensus_span.set_status map_http_status status
+              @opencensus_span.put_attribute "http.status_code", status
+            end
           end
 
           OpenCensus::Trace.end_span @opencensus_span
