@@ -80,6 +80,10 @@ module Google
               options[:render_filter] = ->(value, _doc, *_args) { value.nil? ? nil : value.is_a?(DateTime) ? value.rfc3339(3) : value.to_s }
               options[:parse_filter] = ->(fragment, _doc, *_args) { DateTime.parse(fragment) }
             end
+            if options[:type] == Date
+              options[:render_filter] = ->(value, _doc, *_args) { value.nil? ? nil : value.to_s}
+              options[:parse_filter] = ->(fragment, _doc, *_args) { Date.parse(fragment) }
+            end
 
             options[:render_nil] = true
             options[:getter] = getter_fn(name)
@@ -141,7 +145,7 @@ module Google
 
         def to_json(*a)
           representation = self.class.const_get(:Representation)
-          representation.new(self).to_json(user_options: { skip_undefined: true })
+          representation.new(self).to_hash(user_options: { skip_undefined: true }).to_json(*a)
         end
       end
     end
